@@ -3,7 +3,7 @@ function (x, f, ..., eps = .Machine$double.eps^0.25) {
     n <- length(x)
     res <- matrix(0, n, n)
     ex <- eps * (abs(x) + eps)
-    for (i in 1:n) {
+    for (i in seq_len(n)) {
         x1 <- x2 <- x
         x1[i] <- x[i] + ex[i]
         x2[i] <- x[i] - ex[i]
