@@ -1,4 +1,3 @@
-check_td <-
-function (x, id) {
+check_td <- function (x, id) {
     !all(sapply(split(x, id), function (z) all(z == z[1])))
 }
