@@ -1,4 +1,3 @@
-fastSumID <-
-function (x, group) {
+fastSumID <- function (x, group) {
     as.vector(x = rowsum.default(x, group, reorder = FALSE), mode = "numeric")
 }
