@@ -1,5 +1,4 @@
-fastSumID2 <-
-function (x, group) {
+fastSumID2 <- function (x, group) {
     y <- c(0, cumsum(x)[group])
     out <- y[-1L] - y[-length(y)]
     if (anyNA(out))
