@@ -1,4 +1,4 @@
-format.perc <-
+format_perc <-
 function (probs, digits) {
     paste(format(100 * probs, trim = TRUE, 
                  scientific = FALSE, digits = digits), "%")
