@@ -1,6 +1,6 @@
 
 if (getRversion() >= '2.15.1') 
-    utils::globalVariables(c('data.id', 'timeVar', 'param', 'TermsX', 'TermsZ', 'formYx', 'formYz', 'TermsX.extra', 'TermsZ.extra',
+    utils::globalVariables(c('i', 'data.id', 'timeVar', 'param', 'TermsX', 'TermsZ', 'formYx', 'formYz', 'TermsX.extra', 'TermsZ.extra',
 'extraForm', 'param', 'transFun.value', 'betas.new', 'data.s', 'ids.i', 'transFun.extra', 'indFixed', 'indRandom',
 'alphas.new', 'Ys.extra', 'Dalphas.new', 'betas', 'indBetas', 'W', 'gammas.new', 'object', 'Bs.gammas.new',
 'id', 'ids', 'data.s', 'idVar', 'X', 'Z', 'betas.new', 'densLong', 'sigma.new', 'newdata', 'densRE', 'indFixed', 'indRandom', 'alphas.new', 'weightFun', 'shapes.new', 'max.time', 'estimateWeightFun', 'type','Time', 'obs.times',
