@@ -44,7 +44,7 @@ mvglmer <- function (formulas, data, families, engine = c("JAGS", "STAN"),
                       incr = cumsum(c(0, head(sapply(colmns_HC, length), -1))),
                       SIMPLIFY = FALSE)
     names(RE_inds) <- paste0("RE_ind", seq_along(RE_inds))
-    Data <- c(Data, RE_inds, lapply(colmns_HC, unlist), colmns_nHC)
+    Data <- c(Data, RE_inds, unlist(colmns_HC, recursive = FALSE), colmns_nHC)
     # control
     con <- list(n.processors = parallel::detectCores() - 1, n.chains = 2,
                 working.directory = getwd(), clear.model = TRUE,
@@ -110,7 +110,7 @@ mvglmer <- function (formulas, data, families, engine = c("JAGS", "STAN"),
                         Data$n_RE), file = file.path(con$working.directory, model_name))
     } else {
         cat(data_part(families, lapply(colmns_HC, length), lapply(colmns_nHC, length), 
-                      Data$n_RE, lapply(colmns_HC, unlist), colmns_nHC),
+                      Data$n_RE, colmns_HC, colmns_nHC),
             parameters(families, Data$n_RE),
             transformed_parameters(families, colmns_HC, colmns_nHC, RE_inds),
             model(families, Data$n_RE), generated_quantities(Data$n_RE),
@@ -139,7 +139,7 @@ mvglmer <- function (formulas, data, families, engine = c("JAGS", "STAN"),
         ints
     }
     fit <- if (engine == "JAGS") {
-        jagsUI::jags(data = Data, inits = inits, parameters.to.save = params,
+        jags(data = Data, inits = inits, parameters.to.save = params,
                      model.file = file.path(con$working.directory, model_name),
                      parallel = con$n.processors > 1, n.chains = con$n.chains,
                      n.adapt = con$n.adapt, n.iter = con$n.iter, n.burnin = con$n.burnin,
